=== modified file 'NEWS'
--- NEWS	2010-05-03 04:08:50 +0000
+++ NEWS	2010-05-06 07:48:22 +0000
@@ -114,6 +114,10 @@
 Testing
 *******
 
+* Added ``bzrlib.tests.matchers`` as a place to put matchers, along with
+  our first in-tree matcher. See the module docstring for details.
+  (Robert Collins)
+
 * ``bzr selftest --parallel=subprocess`` now works correctly on win32.
    (Gordon Tyler, #551332)
 

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2010-05-05 00:05:29 +0000
+++ bzrlib/tests/__init__.py	2010-05-06 07:48:22 +0000
@@ -112,13 +112,13 @@
 from bzrlib.tests import (
     test_server,
     TestUtil,
-    treeshape,
     )
 from bzrlib.tests.http_server import HttpServer
 from bzrlib.tests.TestUtil import (
                           TestSuite,
                           TestLoader,
                           )
+from bzrlib.tests.treeshape import build_tree_contents
 from bzrlib.ui import NullProgressView
 from bzrlib.ui.text import TextUIFactory
 import bzrlib.version_info_formats.format_custom
@@ -2578,7 +2578,8 @@
                 content = "contents of %s%s" % (name.encode('utf-8'), end)
                 transport.put_bytes_non_atomic(urlutils.escape(name), content)
 
-    build_tree_contents = treeshape.build_tree_contents
+    def build_tree_contents(self, shape):
+        build_tree_contents(shape)
 
     def assertInWorkingTree(self, path, root_path='.', tree=None):
         """Assert whether path or paths are in the WorkingTree"""
@@ -3733,6 +3734,7 @@
         'bzrlib.tests.test_lru_cache',
         'bzrlib.tests.test_lsprof',
         'bzrlib.tests.test_mail_client',
+        'bzrlib.tests.test_matchers',
         'bzrlib.tests.test_memorytree',
         'bzrlib.tests.test_merge',
         'bzrlib.tests.test_merge3',

=== added file 'bzrlib/tests/matchers.py'
--- bzrlib/tests/matchers.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/matchers.py	2010-05-06 11:08:10 +0000
@@ -0,0 +1,68 @@
+# Copyright (C) 2010 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Matchers for bzrlib.
+
+Primarily test support, Matchers are used by self.assertThat in the bzrlib
+test suite. A matcher is a stateful test helper which can be used to determine
+if a passed object 'matches', much like a regex. If the object does not match
+the mismatch can be described in a human readable fashion. assertThat then
+raises if a mismatch occurs, showing the description as the assertion error.
+
+Matchers are designed to be more reusable and composable than layered
+assertions in Test Case objects, so they are recommended for new testing work.
+"""
+
+__all__ = [
+    'ReturnsUnlockable',
+    ]
+
+from testtools.matchers import Mismatch, Matcher
+
+
+class ReturnsUnlockable(Matcher):
+    """A matcher that checks for the pattern we want lock* methods to have:
+
+    They should return an object with an unlock() method.
+    Calling that method should unlock the original object.
+
+    :ivar lockable_thing: The object which can be locked that will be
+        inspected.
+    """
+
+    def __init__(self, lockable_thing):
+        Matcher.__init__(self)
+        self.lockable_thing = lockable_thing
+
+    def __str__(self):
+        return ('ReturnsUnlockable(lockable_thing=%s)' % 
+            self.lockable_thing)
+
+    def match(self, lock_method):
+        lock_method().unlock()
+        if self.lockable_thing.is_locked():
+            return _IsLocked(self.lockable_thing)
+        return None
+
+
+class _IsLocked(Mismatch):
+    """Something is locked."""
+
+    def __init__(self, lockable_thing):
+        self.lockable_thing = lockable_thing
+
+    def describe(self):
+        return "%s is locked" % self.lockable_thing

=== added file 'bzrlib/tests/test_matchers.py'
--- bzrlib/tests/test_matchers.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/test_matchers.py	2010-05-06 11:08:10 +0000
@@ -0,0 +1,64 @@
+# Copyright (C) 2010 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Tests of bzrlib test matchers."""
+
+from testtools.matchers import *
+
+from bzrlib.tests import TestCase
+from bzrlib.tests.matchers import *
+
+
+class StubTree(object):
+    """Stubg for testing."""
+
+    def __init__(self, lock_status):
+        self._is_locked = lock_status
+
+    def __str__(self):
+        return u'I am da tree'
+
+    def is_locked(self):
+        return self._is_locked
+
+
+class FakeUnlockable(object):
+    """Something that can be unlocked."""
+
+    def unlock(self):
+        pass
+
+
+class TestReturnsUnlockable(TestCase):
+
+    def test___str__(self):
+        matcher = ReturnsUnlockable(StubTree(True))
+        self.assertEqual(
+            'ReturnsUnlockable(lockable_thing=I am da tree)',
+            str(matcher))
+
+    def test_match(self):
+        stub_tree = StubTree(False)
+        matcher = ReturnsUnlockable(stub_tree)
+        self.assertThat(matcher.match(lambda:FakeUnlockable()), Equals(None))
+
+    def test_mismatch(self):
+        stub_tree = StubTree(True)
+        matcher = ReturnsUnlockable(stub_tree)
+        mismatch = matcher.match(lambda:FakeUnlockable())
+        self.assertNotEqual(None, mismatch)
+        self.assertThat(mismatch.describe(), Equals("I am da tree is locked"))
+

=== modified file 'bzrlib/tests/treeshape.py'
--- bzrlib/tests/treeshape.py	2010-05-05 00:05:29 +0000
+++ bzrlib/tests/treeshape.py	2009-03-23 14:59:43 +0000
@@ -41,10 +41,6 @@
 
     The template is built relative to the Python process's current
     working directory.
-
-    ('foo/',) will build a directory.
-    ('foo', 'bar') will write 'bar' to 'foo'
-    ('foo@', 'linktarget') will raise an error
     """
     for tt in template:
         name = tt[0]

=== modified file 'bzrlib/trace.py'
--- bzrlib/trace.py	2010-05-04 06:46:59 +0000
+++ bzrlib/trace.py	2010-03-30 14:44:30 +0000
@@ -111,11 +111,6 @@
 
 
 def note(*args, **kwargs):
-    """Output a note to the user.
-
-    Takes the same parameters as logging.info.
-    :return: None
-    """
     # FIXME note always emits utf-8, regardless of the terminal encoding
     #
     # FIXME: clearing the ui and then going through the abstract logging

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2010-05-04 06:22:51 +0000
+++ bzrlib/transport/__init__.py	2010-04-16 07:56:51 +0000
@@ -539,9 +539,6 @@
 
         This function will only be defined for Transports which have a
         physical local filesystem representation.
-
-        :raises errors.NotLocalUrl: When no local path representation is
-            available.
         """
         raise errors.NotLocalUrl(self.abspath(relpath))
 

